import { Component, Input, ViewContainerRef, ViewChild, EventEmitter, Output } from '@angular/core';
import { BehaviorSubject } from 'rxjs';
import { ComponentFactoryService } from '../../providers/component-factory.service';
var StepperViewComponent = /** @class */ (function () {
    function StepperViewComponent(componentSvc) {
        this.componentSvc = componentSvc;
        this.navigate = new EventEmitter();
    }
    StepperViewComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        this.activeItem = (this.activeListItem) ? this.activeListItem['value'] : null;
        this.handleItemChange(this.activeItem);
        this.activeItemSubscription = this.activeListItem
            .subscribe(function (item) { return _this.handleItemChange(item); });
    };
    StepperViewComponent.prototype.ngOnDestroy = function () {
        this.activeItemSubscription.unsubscribe();
    };
    StepperViewComponent.prototype.handleItemChange = function (activeItem) {
        var _this = this;
        this.activeItem = activeItem;
        if (!this.activeItem.component) {
            this.viewContainerRef.remove();
            (this.currentComponent) ? this.currentComponent.destroy() : null;
        }
        else {
            this.viewContainerRef.remove();
            this.currentComponent = this.componentSvc
                .createComponent(this.viewContainerRef, this.activeItem.component);
            var backSub_1;
            var nextSub_1;
            if (this.currentComponent && this.currentComponent['instance']) {
                if (this.currentComponent.instance.back instanceof EventEmitter) {
                    backSub_1 = this.currentComponent
                        .instance.back.subscribe(function () { return _this.navigate.emit(false); });
                }
                if (this.currentComponent.instance.next instanceof EventEmitter) {
                    nextSub_1 = this.currentComponent
                        .instance.next.subscribe(function () { return _this.navigate.emit(true); });
                }
                this.currentComponent.onDestroy(function () {
                    if (backSub_1) {
                        backSub_1.unsubscribe();
                    }
                    if (nextSub_1) {
                        nextSub_1.unsubscribe();
                    }
                });
            }
        }
    };
    StepperViewComponent.decorators = [
        { type: Component, args: [{
                    selector: 'stepper-view-cmp',
                    template: "\n    <ng-template #stepperview></ng-template>\n  "
                },] },
    ];
    /** @nocollapse */
    StepperViewComponent.ctorParameters = function () { return [
        { type: ComponentFactoryService, },
    ]; };
    StepperViewComponent.propDecorators = {
        "activeListItem": [{ type: Input },],
        "navigate": [{ type: Output },],
        "viewContainerRef": [{ type: ViewChild, args: ['stepperview', {
                        read: ViewContainerRef
                    },] },],
    };
    return StepperViewComponent;
}());
export { StepperViewComponent };
//# sourceMappingURL=stepper-view.component.js.map